@@ -312,7 +312,7 @@ class CCT(nn.Module):
         input_size=(32, 32),
         cnn=True,
         cnn_in_channels=3,
-        minimum_cnn_out_channels=16,
+        cnn_out_channels=16,
         cnn_kernel_size=3,
         cnn_kernel_stride=1,
         cnn_padding="same",
@@ -365,7 +365,7 @@ class CCT(nn.Module):
             input_size=input_size,
             cnn=cnn,
             cnn_in_channels=cnn_in_channels,
-            minimum_cnn_out_channels=minimum_cnn_out_channels,
+            cnn_out_channels=cnn_out_channels,
             cnn_kernel_size=cnn_kernel_size,
             cnn_kernel_stride=cnn_kernel_stride,
             cnn_padding=cnn_padding,
